==> zio-aws-workspaces_2.13-5.17.295.10-sources.jar: zio/aws/workspaces/model/CreateWorkspaceImageRequest.scala <==
package zio.aws.workspaces.model
import zio.aws.workspaces.model.primitives.{
  WorkspaceId,
  WorkspaceImageDescription,
  WorkspaceImageName
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateWorkspaceImageRequest(
    name: WorkspaceImageName,
    description: WorkspaceImageDescription,
    workspaceId: WorkspaceId,
    tags: Optional[Iterable[zio.aws.workspaces.model.Tag]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.workspaces.model.CreateWorkspaceImageRequest = {
    import CreateWorkspaceImageRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.workspaces.model.CreateWorkspaceImageRequest
      .builder()
      .name(WorkspaceImageName.unwrap(name): java.lang.String)
      .description(
        WorkspaceImageDescription.unwrap(description): java.lang.String
      )
      .workspaceId(WorkspaceId.unwrap(workspaceId): java.lang.String)
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .build()
  }
  def asReadOnly
      : zio.aws.workspaces.model.CreateWorkspaceImageRequest.ReadOnly =
    zio.aws.workspaces.model.CreateWorkspaceImageRequest.wrap(buildAwsValue())
}
object CreateWorkspaceImageRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.workspaces.model.CreateWorkspaceImageRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.workspaces.model.CreateWorkspaceImageRequest =
      zio.aws.workspaces.model.CreateWorkspaceImageRequest(
        name,
        description,
        workspaceId,
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def name: WorkspaceImageName
    def description: WorkspaceImageDescription
    def workspaceId: WorkspaceId
    def tags: Optional[List[zio.aws.workspaces.model.Tag.ReadOnly]]
    def getName: ZIO[Any, Nothing, WorkspaceImageName] = ZIO.succeed(name)
    def getDescription: ZIO[Any, Nothing, WorkspaceImageDescription] =
      ZIO.succeed(description)
    def getWorkspaceId: ZIO[Any, Nothing, WorkspaceId] =
      ZIO.succeed(workspaceId)
    def getTags
        : ZIO[Any, AwsError, List[zio.aws.workspaces.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.workspaces.model.CreateWorkspaceImageRequest
  ) extends zio.aws.workspaces.model.CreateWorkspaceImageRequest.ReadOnly {
    override val name: WorkspaceImageName =
      zio.aws.workspaces.model.primitives.WorkspaceImageName(impl.name())
    override val description: WorkspaceImageDescription =
      zio.aws.workspaces.model.primitives
        .WorkspaceImageDescription(impl.description())
    override val workspaceId: WorkspaceId =
      zio.aws.workspaces.model.primitives.WorkspaceId(impl.workspaceId())
    override val tags: Optional[List[zio.aws.workspaces.model.Tag.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.workspaces.model.Tag.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.workspaces.model.CreateWorkspaceImageRequest
  ): zio.aws.workspaces.model.CreateWorkspaceImageRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-workspaces_3-5.17.295.14-sources.jar: zio/aws/workspaces/model/CreateWorkspaceImageRequest.scala <==
package zio.aws.workspaces.model
import zio.aws.workspaces.model.primitives.{
  WorkspaceId,
  WorkspaceImageDescription,
  WorkspaceImageName
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class CreateWorkspaceImageRequest(
    name: WorkspaceImageName,
    description: WorkspaceImageDescription,
    workspaceId: WorkspaceId,
    tags: Optional[Iterable[zio.aws.workspaces.model.Tag]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.workspaces.model.CreateWorkspaceImageRequest = {
    import CreateWorkspaceImageRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.workspaces.model.CreateWorkspaceImageRequest
      .builder()
      .name(WorkspaceImageName.unwrap(name): java.lang.String)
      .description(
        WorkspaceImageDescription.unwrap(description): java.lang.String
      )
      .workspaceId(WorkspaceId.unwrap(workspaceId): java.lang.String)
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .build()
  }
  def asReadOnly
      : zio.aws.workspaces.model.CreateWorkspaceImageRequest.ReadOnly =
    zio.aws.workspaces.model.CreateWorkspaceImageRequest.wrap(buildAwsValue())
}
object CreateWorkspaceImageRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.workspaces.model.CreateWorkspaceImageRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.workspaces.model.CreateWorkspaceImageRequest =
      zio.aws.workspaces.model.CreateWorkspaceImageRequest(
        name,
        description,
        workspaceId,
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def name: WorkspaceImageName
    def description: WorkspaceImageDescription
    def workspaceId: WorkspaceId
    def tags: Optional[List[zio.aws.workspaces.model.Tag.ReadOnly]]
    def getName: ZIO[Any, Nothing, WorkspaceImageName] = ZIO.succeed(name)
    def getDescription: ZIO[Any, Nothing, WorkspaceImageDescription] =
      ZIO.succeed(description)
    def getWorkspaceId: ZIO[Any, Nothing, WorkspaceId] =
      ZIO.succeed(workspaceId)
    def getTags
        : ZIO[Any, AwsError, List[zio.aws.workspaces.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.workspaces.model.CreateWorkspaceImageRequest
  ) extends zio.aws.workspaces.model.CreateWorkspaceImageRequest.ReadOnly {
    override val name: WorkspaceImageName =
      zio.aws.workspaces.model.primitives.WorkspaceImageName(impl.name())
    override val description: WorkspaceImageDescription =
      zio.aws.workspaces.model.primitives
        .WorkspaceImageDescription(impl.description())
    override val workspaceId: WorkspaceId =
      zio.aws.workspaces.model.primitives.WorkspaceId(impl.workspaceId())
    override val tags: Optional[List[zio.aws.workspaces.model.Tag.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.workspaces.model.Tag.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.workspaces.model.CreateWorkspaceImageRequest
  ): zio.aws.workspaces.model.CreateWorkspaceImageRequest.ReadOnly =
    new Wrapper(impl)
}
